jaspr_current library

Support for doing something awesome.

More dartdocs go here.

Classes

BusyStatusChanged
Event that is added to the state stream when the busy status of the view model changes.
Current<T extends CurrentViewModel>
Used to provide shared state and functions across specific scopes of your application, or the entire application itself.
CurrentApp<T extends CurrentViewModel>
This widget is not intended to be created manually and is used by the Current widget.
CurrentBoolProperty
An CurrentProperty with similar characteristics as a an ordinary dart bool object
CurrentCloneable<T>
CurrentComponent<T extends CurrentViewModel>
Base class for any component that needs to be updated when the state of your component changes.
CurrentDateTimeProperty
An CurrentProperty with similar characteristics as a an ordinary dart DateTime object
CurrentDoubleProperty
An CurrentProperty with similar characteristics of dart double objects
CurrentIntProperty
An CurrentProperty with similar characteristics of dart int objects
CurrentListProperty<T>
An CurrentProperty with similar characteristics as a dart List<T>
CurrentMapProperty<K, V>
An CurrentProperty with similar characteristics as a dart Map<K, V>
CurrentNullableBoolProperty
An CurrentProperty with similar characteristics as a an ordinary dart bool object.
CurrentNullableDateTimeProperty
An CurrentProperty with similar characteristics as a an ordinary dart bool object.
CurrentNullableDoubleProperty
An CurrentProperty with similar characteristics of dart double objects
CurrentNullableIntProperty
An CurrentProperty with similar characteristics of dart int objects
CurrentNullableStringProperty
An CurrentProperty with similar characteristics as a dart String object
CurrentProperty<T>
Contains any object that will notify any listeners when its value is changed.
CurrentState<T extends CurrentComponent<CurrentViewModel>, E extends CurrentViewModel>
Base class for your CurrentComponents accompanying State class.
CurrentStateChanged<T>
The event that is added to the State stream.
CurrentStateViewModel
A ViewModel is an abstraction of the view it is bound to and represents the current state of the data in your model.
CurrentStringProperty
An CurrentProperty with similar characteristics as a dart String object
CurrentValue<T>
Base class for CurrentProperty
CurrentViewModel
A ViewModel is an abstraction of the view it is bound to and represents the current state of the data in your model.
CurrentViewModelBinding
Contract for helper objects that need to attach themselves to a CurrentStateViewModel after all CurrentProperty values have been initialized.
ErrorEvent<T>
The event that is added to the Error stream.

Functions

createNullProperty<T>({String? propertyName}) CurrentProperty<T?>
Short hand helper function for initializing an CurrentProperty with a null value.
createProperty<T>(T value, {String? propertyName}) CurrentProperty<T>
Short hand helper function for initializing an CurrentProperty.

Exceptions / Errors

CurrentException
Base class for any Current specific exception
CurrentIntPropertyInvalidArithmaticException
Thrown when a CurrentIntProperty arithmetic function cannot convert its numeric result into the explicitly requested generic type.
CurrentPropertyException
CurrentPropertyNullValueException
Thrown when an not-null-safe action is performed on a Nullable Current Property, and the underlying value was null.
CurrentViewModelAlreadyAssignedException
Thrown when a CurrentViewModel is assigned to a CurrentState, but that CurrentViewModel is already assigned to a different CurrentState.
PropertyNotAssignedToCurrentViewModelException
Thrown when an CurrentProperty value is changed and attempts to update the UI, but has not been added to the currentProps property of the associated CurrentViewModel